@@ -26,8 +26,10 @@ from airflow.exceptions import AirflowException, AirflowFailException
 from airflow.hooks.base import BaseHook
 from airflow.models import BaseOperator, SkipMixin
 from airflow.providers.common.sql.hooks.sql import DbApiHook, fetch_all_handler, return_single_query_results
+from airflow.utils.helpers import merge_dicts
 
 if TYPE_CHECKING:
+    from airflow.providers.openlineage.extractors import OperatorLineage
     from airflow.utils.context import Context
 
 
@@ -290,10 +292,72 @@ class SQLExecuteQueryOperator(BaseSQLOperator):
         if isinstance(self.parameters, str):
             self.parameters = ast.literal_eval(self.parameters)
 
+    def get_openlineage_facets_on_start(self) -> OperatorLineage | None:
+        try:
+            from airflow.providers.openlineage.sqlparser import SQLParser
+        except ImportError:
+            return None
+
+        hook = self.get_db_hook()
+
+        connection = hook.get_connection(getattr(hook, hook.conn_name_attr))
+        try:
+            database_info = hook.get_openlineage_database_info(connection)
+        except AttributeError:
+            self.log.debug("%s has no database info provided", hook)
+            database_info = None
+
+        if database_info is None:
+            return None
+
+        try:
+            sql_parser = SQLParser(
+                dialect=hook.get_openlineage_database_dialect(connection),
+                default_schema=hook.get_openlineage_default_schema(),
+            )
+        except AttributeError:
+            self.log.debug("%s failed to get database dialect", hook)
+            return None
+
+        operator_lineage = sql_parser.generate_openlineage_metadata_from_sql(
+            sql=self.sql,
+            hook=hook,
+            database_info=database_info,
+            database=self.database,
+            sqlalchemy_engine=hook.get_sqlalchemy_engine(),
+        )
+
+        return operator_lineage
+
+    def get_openlineage_facets_on_complete(self, task_instance) -> OperatorLineage | None:
+        operator_lineage = self.get_openlineage_facets_on_start() or OperatorLineage()
+
+        try:
+            from airflow.providers.openlineage.extractors import OperatorLineage
+        except ImportError:
+            return operator_lineage
+
+        hook = self.get_db_hook()
+        try:
+            database_specific_lineage = hook.get_openlineage_database_specific_lineage(task_instance)
+        except AttributeError:
+            database_specific_lineage = None
+
+        if database_specific_lineage is None:
+            return operator_lineage
+
+        return OperatorLineage(
+            inputs=operator_lineage.inputs + database_specific_lineage.inputs,
+            outputs=operator_lineage.outputs + database_specific_lineage.outputs,
+            run_facets=merge_dicts(operator_lineage.run_facets, database_specific_lineage.run_facets),
+            job_facets=merge_dicts(operator_lineage.job_facets, database_specific_lineage.job_facets),
+        )
+
 
 class SQLColumnCheckOperator(BaseSQLOperator):
     """
     Performs one or more of the templated checks in the column_checks dictionary.
+
     Checks are performed on a per-column basis specified by the column_mapping.
 
     Each check can take one or more of the following options:
@@ -540,6 +604,7 @@ class SQLColumnCheckOperator(BaseSQLOperator):
 class SQLTableCheckOperator(BaseSQLOperator):
     """
     Performs one or more of the checks provided in the checks dictionary.
+
     Checks should be written to return a boolean result.
 
     :param table: the table to run checks on
@@ -650,10 +715,11 @@ class SQLTableCheckOperator(BaseSQLOperator):
 
 class SQLCheckOperator(BaseSQLOperator):
     """
-    Performs checks against a db. The ``SQLCheckOperator`` expects
-    a sql query that will return a single row. Each value on that
-    first row is evaluated using python ``bool`` casting. If any of the
-    values return ``False`` the check is failed and errors out.
+    Performs checks against a db.
+
+    The ``SQLCheckOperator`` expects a sql query that will return a single row.
+    Each value on that first row is evaluated using python ``bool`` casting.
+    If any of the values return ``False`` the check is failed and errors out.
 
     Note that Python bool casting evals the following as ``False``:
 
@@ -808,8 +874,7 @@ class SQLValueCheckOperator(BaseSQLOperator):
 
 class SQLIntervalCheckOperator(BaseSQLOperator):
     """
-    Checks that the values of metrics given as SQL expressions are within
-    a certain tolerance of the ones from days_back before.
+    Check that metrics given as SQL expressions are within tolerance of the ones from days_back before.
 
     :param table: the table name
     :param conn_id: the connection ID used to connect to the database.
@@ -946,9 +1011,9 @@ class SQLIntervalCheckOperator(BaseSQLOperator):
 
 class SQLThresholdCheckOperator(BaseSQLOperator):
     """
-    Performs a value check using sql code against a minimum threshold
-    and a maximum threshold. Thresholds can be in the form of a numeric
-    value OR a sql statement that results a numeric.
+    Performs a value check using sql code against a minimum threshold and a maximum threshold.
+
+    Thresholds can be in the form of a numeric value OR a sql statement that results a numeric.
 
     :param sql: the sql to be executed. (templated)
     :param conn_id: the connection ID used to connect to the database.
@@ -1028,6 +1093,7 @@ class SQLThresholdCheckOperator(BaseSQLOperator):
     def push(self, meta_data):
         """
         Optional: Send data check info and metadata to an external database.
+
         Default functionality will log metadata.
         """
         info = "\n".join(f"""{key}: {item}""" for key, item in meta_data.items())
